@@ -23,7 +23,7 @@ class AliddnsCore:
         self._access_key = access_key
         self._domain = domain
         self._sub_domain = sub_domain
-        self._update_time = ""
+        self._update_time = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
         self._Aliyun_API_Type = "A"
         self._Aliyun_API_V6_Type = "AAAA"
         self._record = None
@@ -68,17 +68,17 @@ class AliddnsCore:
         """Return the last ipv6 record of ddns."""
         return self._last_record_v6
 
-    def AliyunSignature(self,parameters):
+    def _AliyunSignature(self,parameters):
         sortedParameters = sorted(parameters.items(), key=lambda parameters: parameters[0])
         canonicalizedQueryString = ''
         for (k, v) in sortedParameters:
-            canonicalizedQueryString += '&' + self.CharacterEncode(k) + '=' + self.CharacterEncode(v)
-        stringToSign = 'GET&%2F&' + self.CharacterEncode(canonicalizedQueryString[1:])
+            canonicalizedQueryString += '&' + self._CharacterEncode(k) + '=' + self._CharacterEncode(v)
+        stringToSign = 'GET&%2F&' + self._CharacterEncode(canonicalizedQueryString[1:])
         h = hmac.new((self._access_key + "&").encode('ASCII'), stringToSign.encode('ASCII'), sha1)
         signature = base64.encodebytes(h.digest()).strip()
         return signature
 
-    def CharacterEncode(self,encodeStr):
+    def _CharacterEncode(self,encodeStr):
         encodeStr = str(encodeStr)
         res = quote(encodeStr.encode('utf-8'), '')
         res = res.replace('+', '%20')
@@ -86,7 +86,7 @@ class AliddnsCore:
         res = res.replace('%7E', '~')
         return res
 
-    def AliyunAPIPOST(self,Aliyun_API_Action):
+    def _AliyunAPIPOST(self,Aliyun_API_Action):
         Aliyun_API_SD = {
             'Format': 'json',
             'Version': '2015-01-09',
@@ -99,10 +99,10 @@ class AliddnsCore:
         }
         return Aliyun_API_SD
 
-    def check_record_id(self,sub_domain,domain):
-        Aliyun_API_Post = self.AliyunAPIPOST('DescribeDomainRecords')
+    def _check_record_id(self,sub_domain,domain):
+        Aliyun_API_Post = self._AliyunAPIPOST('DescribeDomainRecords')
         Aliyun_API_Post['DomainName'] = domain
-        Aliyun_API_Post['Signature'] = self.AliyunSignature(Aliyun_API_Post)
+        Aliyun_API_Post['Signature'] = self._AliyunSignature(Aliyun_API_Post)
         Aliyun_API_Post = urlencode(Aliyun_API_Post)
         Aliyun_API_Request = get(self._Aliyun_API_URL + Aliyun_API_Post)
 
@@ -130,99 +130,129 @@ class AliddnsCore:
             return -1
 
     
-    def old_ip(self,Aliyun_API_RecordID):
-        Aliyun_API_Post = self.AliyunAPIPOST('DescribeDomainRecordInfo')
+    def _old_ip(self,Aliyun_API_RecordID):
+        Aliyun_API_Post = self._AliyunAPIPOST('DescribeDomainRecordInfo')
         Aliyun_API_Post['RecordId'] = Aliyun_API_RecordID
-        Aliyun_API_Post['Signature'] = self.AliyunSignature(Aliyun_API_Post)
+        Aliyun_API_Post['Signature'] = self._AliyunSignature(Aliyun_API_Post)
         Aliyun_API_Post = urlencode(Aliyun_API_Post)
         Aliyun_API_Request = get(self._Aliyun_API_URL + Aliyun_API_Post)
         result = JSONDecoder().decode(Aliyun_API_Request.text)
         return result.get('Value','no record')
 
-    def add_dns(self,domainIP, Aliyun_API_Type):
-        Aliyun_API_Post = self.AliyunAPIPOST('AddDomainRecord')
+    def _add_dns(self,domainIP, Aliyun_API_Type):
+        Aliyun_API_Post = self._AliyunAPIPOST('AddDomainRecord')
         Aliyun_API_Post['DomainName'] = self.domain
         Aliyun_API_Post['RR'] = self._sub_domain
         Aliyun_API_Post['Type'] = Aliyun_API_Type
         Aliyun_API_Post['Value'] = domainIP
-        Aliyun_API_Post['Signature'] = self.AliyunSignature(Aliyun_API_Post)
+        Aliyun_API_Post['Signature'] = self._AliyunSignature(Aliyun_API_Post)
         Aliyun_API_Post = urlencode(Aliyun_API_Post)
         get(self._Aliyun_API_URL + Aliyun_API_Post)
 
-    def delete_dns(self,Aliyun_API_RecordID):
-        Aliyun_API_Post = self.AliyunAPIPOST('DeleteDomainRecord')
+    def _delete_dns(self,Aliyun_API_RecordID):
+        Aliyun_API_Post = self._AliyunAPIPOST('DeleteDomainRecord')
         Aliyun_API_Post['RecordId'] = Aliyun_API_RecordID
-        Aliyun_API_Post['Signature'] = self.AliyunSignature(Aliyun_API_Post)
+        Aliyun_API_Post['Signature'] = self._AliyunSignature(Aliyun_API_Post)
         Aliyun_API_Post = urlencode(Aliyun_API_Post)
         get(self._Aliyun_API_URL + Aliyun_API_Post)
 
-    def update_dns(self,Aliyun_API_RecordID, Aliyun_API_Value, Aliyun_API_Type):
-        Aliyun_API_Post = self.AliyunAPIPOST('UpdateDomainRecord')
+    def _update_dns(self,Aliyun_API_RecordID, Aliyun_API_Value, Aliyun_API_Type):
+        Aliyun_API_Post = self._AliyunAPIPOST('UpdateDomainRecord')
         Aliyun_API_Post['RecordId'] = Aliyun_API_RecordID
         Aliyun_API_Post['RR'] = self._sub_domain
         Aliyun_API_Post['Type'] = Aliyun_API_Type
         Aliyun_API_Post['Value'] = Aliyun_API_Value
-        Aliyun_API_Post['Signature'] = self.AliyunSignature(Aliyun_API_Post)
+        Aliyun_API_Post['Signature'] = self._AliyunSignature(Aliyun_API_Post)
         Aliyun_API_Post = urlencode(Aliyun_API_Post)
         get(self._Aliyun_API_URL + Aliyun_API_Post)
 
-    def set_dns(self,Aliyun_API_RecordID, Aliyun_API_Enabled):
-        Aliyun_API_Post = self.AliyunAPIPOST('SetDomainRecordStatus')
+    def _set_dns(self,Aliyun_API_RecordID, Aliyun_API_Enabled):
+        Aliyun_API_Post = self._AliyunAPIPOST('SetDomainRecordStatus')
         Aliyun_API_Post['RecordId'] = Aliyun_API_RecordID
         Aliyun_API_Post['Status'] = "Enable" if Aliyun_API_Enabled else "Disable"
-        Aliyun_API_Post['Signature'] = self.AliyunSignature(Aliyun_API_Post)
+        Aliyun_API_Post['Signature'] = self._AliyunSignature(Aliyun_API_Post)
         Aliyun_API_Post = urlencode(Aliyun_API_Post)
         get(self._Aliyun_API_URL + Aliyun_API_Post)
 
-    def need_check_record_id(self, update_ip_v6):
+    def _need_check_record_id(self, update_ip_v6):
         if self._rc_record_id < 0 :
             return True
         if update_ip_v6 and self._rc_record_v6_id < 0:
             return True
         return False
 
-    def update_dns_record(self, rc_value, rc_record_id, api_type, record_ip_v6=False):
+    def _update_dns_record(self, rc_value, rc_record_id, api_type, record_ip_v6=False):
         if rc_record_id < 0:
-            self.add_dns(rc_value, api_type)
+            self._add_dns(rc_value, api_type)
+            self.update_time_stamp()
         else:         
-            rc_value_old = self.old_ip(rc_record_id)
+            rc_value_old = self._old_ip(rc_record_id)
             if rc_value != rc_value_old:
                 if record_ip_v6 :
                     self._last_record_v6 = rc_value_old
                 else :
                     self._last_record = rc_value_old
-                self.update_dns(rc_record_id, rc_value, api_type)
-
+                self._update_dns(rc_record_id, rc_value, api_type)
+                self.update_time_stamp()
+                
         if record_ip_v6 :
             self._record_v6 = rc_value
         else:      
             self._record = rc_value
-
-        self._update_time = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
+        
 
     def update_ddns(self, ddns_record, ddns_record_v6=None):
 
-        if self.need_check_record_id(ddns_record_v6):
-            if self.check_record_id(self._sub_domain, self._domain) < 0:
+        if self._need_check_record_id(ddns_record_v6):
+            if self._check_record_id(self._sub_domain, self._domain) < 0:
                 self._state = "network error"
                 return False
 
-        self.update_dns_record(ddns_record, self._rc_record_id, self._Aliyun_API_Type)
+        self._update_dns_record(ddns_record, self._rc_record_id, self._Aliyun_API_Type)
         if ddns_record_v6:
-            self.update_dns_record(ddns_record_v6, self._rc_record_v6_id, 
+            self._update_dns_record(ddns_record_v6, self._rc_record_v6_id, 
                 self._Aliyun_API_V6_Type, True)
 
         return True
 
     def init_ddns_info(self):
 
-        if self.need_check_record_id(True):
-            if self.check_record_id(self._sub_domain, self._domain) < 0:
+        if self._need_check_record_id(True):
+            if self._check_record_id(self._sub_domain, self._domain) < 0:
                 self._state = "network error"
                 return False
 
+        self.get_current_ddns()
+        return True
+
+    def update_time_stamp(self):
+
+        self._update_time = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
+
+    def get_current_ddns(self):
+
         if self._rc_record_id >= 0 :
-            self._record = self.old_ip(self._rc_record_id)
+            self._record = self._old_ip(self._rc_record_id)
 
         if self._rc_record_v6_id >= 0 :
-            self._record_v6 = self.old_ip(self._rc_record_v6_id)
+            self._record_v6 = self._old_ip(self._rc_record_v6_id)
+
+    def delete_ddns(self, remove_ipv6=True):
+
+        if self._rc_record_id >= 0 :
+            self._delete_dns(self._rc_record_id)
+            self._rc_record_id = -1
+
+        if remove_ipv6 :
+            if self._rc_record_v6_id >= 0 :
+                self._delete_dns(self._rc_record_v6_id)
+                self._rc_record_v6_id = -1
+
+    def enable_ddns(self, en_ddns, remove_ipv6=True):
+
+        if self._rc_record_id >= 0 :
+            self._set_dns(self._rc_record_id, en_ddns)
+
+        if remove_ipv6 :
+            if self._rc_record_v6_id >= 0 :
+                self._set_dns(self._rc_record_v6_id, en_ddns)
\ No newline at end of file
